==> compass-metadata-0.1.55-sources.jar: com/xforceplus/ultraman/app/compass/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.compass.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2022-06-06
 */

public class PageMeta {
    public interface BillManager {
        static String code() {
            return "billManager";
        }
        static String name() {
            return "账单管理";
        }
    }
    public interface Billnvoice {
        static String code() {
            return "billnvoice";
        }
        static String name() {
            return "账单一级明细";
        }
    }
    public interface Billdetails {
        static String code() {
            return "billdetails";
        }
        static String name() {
            return "账单二级明细";
        }
    }
    public interface BillManagerSupplier {
        static String code() {
            return "billManagerSupplier";
        }
        static String name() {
            return "账单管理销方";
        }
    }
    public interface YearBill {
        static String code() {
            return "yearBill";
        }
        static String name() {
            return "年度账单";
        }
    }
    public interface YearBillMain {
        static String code() {
            return "yearBillMain";
        }
        static String name() {
            return "年度账单主信息";
        }
    }
    public interface YearBillDetail {
        static String code() {
            return "yearBillDetail";
        }
        static String name() {
            return "年度账单明细";
        }
    }
    public interface SalesbillUpload {
        static String code() {
            return "salesbillUpload";
        }
        static String name() {
            return "业务单上传履历";
        }
    }
    public interface MiroResult {
        static String code() {
            return "miroResult";
        }
        static String name() {
            return "MIRO页面";
        }
    }
}

==> compass-metadata-0.1.222-sources.jar: com/xforceplus/ultraman/app/compass/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.compass.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2025-09-23
 */

public class PageMeta {
    public interface Billdetails {
        static String code() {
            return "billdetails";
        }
        static String name() {
            return "账单二级明细";
        }
    }
    public interface Billnvoice {
        static String code() {
            return "billnvoice";
        }
        static String name() {
            return "账单一级明细";
        }
    }
    public interface YearBillDetail {
        static String code() {
            return "yearBillDetail";
        }
        static String name() {
            return "年度账单明细";
        }
    }
    public interface YearBillMain {
        static String code() {
            return "yearBillMain";
        }
        static String name() {
            return "年度账单主信息";
        }
    }
    public interface YearBill {
        static String code() {
            return "yearBill";
        }
        static String name() {
            return "年度账单";
        }
    }
    public interface BillManager {
        static String code() {
            return "billManager";
        }
        static String name() {
            return "账单管理";
        }
    }
    public interface BillManagerSupplier {
        static String code() {
            return "billManagerSupplier";
        }
        static String name() {
            return "账单管理销方";
        }
    }
    public interface NoCoopSalesbill {
        static String code() {
            return "noCoopSalesbill";
        }
        static String name() {
            return "非协同业务单";
        }
    }
    public interface BizOrderSap {
        static String code() {
            return "bizOrderSap";
        }
        static String name() {
            return "统一单据";
        }
    }
    public interface MiroResult {
        static String code() {
            return "miroResult";
        }
        static String name() {
            return "MIRO页面";
        }
    }
    public interface SalesbillUpload {
        static String code() {
            return "salesbillUpload";
        }
        static String name() {
            return "业务单上传履历";
        }
    }
    public interface ItemMappingConfig {
        static String code() {
            return "itemMappingConfig";
        }
        static String name() {
            return "商品映射表";
        }
    }
    public interface NoCoopSettlement {
        static String code() {
            return "noCoopSettlement";
        }
        static String name() {
            return "非协同结算单";
        }
    }
}
